@@ -1,4 +1,4 @@
-`as.paleoTS` <-
+as.paleoTS <-
 function (mm, vv, nn, tt, MM=NULL, genpars=NULL, label="", start.age=NULL)
 # converts vectors of observed mean, variances, N's, ages (time steps),
 # true means (for simulated series), and label to an object of class 'paleoTS'
